import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.List;

import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.EntityTransaction;
import javax.persistence.Persistence;

public class HelloWorld {
	
	private static String PERSISTENCE_UNIT_NAME = "hello-world";
	EntityManagerFactory emf;
	
	HelloWorld(EntityManagerFactory emf) {
		this.emf = emf;
	}
	
	public static void main(String[] args) throws IOException {
		EntityManagerFactory emf = Persistence.createEntityManagerFactory(PERSISTENCE_UNIT_NAME);
		
		HelloWorld hello = new HelloWorld(emf);
		hello.console();
		
		emf.close();
	}
	
	public void console() throws IOException {
		BufferedReader in = new BufferedReader(new InputStreamReader(System.in));
		String line = null;
		System.out.print("\n> ");
		while ( (line = in.readLine()) != null) {
			if ("exit".equals(line)) {
				break;
			} else if ("save".equals(line)) {
				save();
			} else if ("clean".equals(line)) {	
				clean();
			} else if ("find".equals(line)) {	
				find();
			} else if (line.length()>0) {
				System.out.println("unrecognized command");	
			}
			System.out.print("\n> ");			
		}
	}
	
	private void clean() {
		EntityManager em = null;
		EntityTransaction tx = null;
		try {
			em = emf.createEntityManager();
			tx = em.getTransaction();
			tx.begin();
			 
			Greeting g = new Greeting();
			g.setId(1);
			g = em.merge(g);
			em.remove(g);
			 
			tx.commit();		
		} catch (RuntimeException re) {
			re.printStackTrace();
			try {
				tx.rollback();
			} catch (RuntimeException ignore) {}
		} finally {
			em.close();
		}
		
	}

	private void save() {
		EntityManager em = null;
		EntityTransaction tx = null;
		try {
			em = emf.createEntityManager();
			tx = em.getTransaction();
			tx.begin();
			 
			Greeting g = new Greeting();
			g.setId(1);
			g.setMessage("hello world");
			em.persist(g);
			 
			tx.commit();		
		} catch (RuntimeException re) {
			re.printStackTrace();
			try {
				tx.rollback();
			} catch (RuntimeException ignore) {}
		} finally {
			em.close();
		}
	}

	private void find() {
		EntityManager em = null;
		EntityTransaction tx = null;
		try {
			em = emf.createEntityManager();
			tx = em.getTransaction();
			tx.begin();
			
			List list = em.createQuery("select g from Greeting g").getResultList();
			if (list!=null && list.size()>0) {
				int size = list.size();
				System.out.println(size + " Greeting(s) found:");
				for (int i = 0; i < size; i++) {
					System.out.println("	Greeting["+i+"]: " + list.get(i));	
				}
			} else {
				System.out.println("no Greetings found");
			}
			 
			tx.commit();		
		} catch (RuntimeException re) {
			re.printStackTrace();
			try {
				tx.rollback();
			} catch (RuntimeException ignore) {}
		} finally {
			em.close();
		}
	}

}